@@ -10,7 +10,7 @@ use UNIVERSAL;
 use Exporter;
 
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 our $DEBUG;
 
 our @ISA = qw(Exporter);
@@ -23,6 +23,8 @@ our @EXPORT_OK = qw(
     min
     sum
     cast
+    upper
+    lower
     now
     nextval
     currval
@@ -185,6 +187,16 @@ sub cast {
 }
 
 
+sub upper {
+    return do_function('UPPER', @_);
+}
+
+
+sub lower {
+    return do_function('LOWER', @_);
+}
+
+
 sub now {
     return do_function('NOW');
 }
@@ -595,6 +607,14 @@ in {...definition...}. Each table can only be defined once.
 
 
 
+=head2 upper
+
+
+
+=head2 lower
+
+
+
 =head2 now
 
 
