@@ -28,7 +28,12 @@ sub Default {
         column => [name => 'id',  type => 'INTEGER', primary => 1],
         column => [name => 'scalar',type => 'INTEGER', default => 1],
         column => [name => 'sub',type => 'INTEGER', default => sub {1+1}],
-        column => [name => 'binary',type => 'BLOB', bind_type => SQL_BLOB],
+        column => [
+            name => 'binary',
+            type => 'BLOB',
+            type_pg => 'BYTEA',
+            bind_type_pg => 'pg bind type',
+        ],
     ];
 }
 
